@@ -6,8 +6,10 @@
 // atom names can be specified, for example HB1|HB2.  A maximum ppm range
 // from peak position to resonance position can be specified for each axis.
 //
-#include <string.h>		// Use strchr(), strncmp()
 #include <ctype.h>		// Use isspace()
+#include <math.h>		// use fabs()
+#include <stdlib.h>		// use size_t
+#include <string.h>		// Use strchr(), strncmp()
 
 #include "assignguess.h"
 #include "atom.h"		// Use Atom
@@ -15,7 +17,7 @@
 #include "crosspeak.h"		// Use CrossPeak
 #include "group.h"		// Use Group
 #include "memalloc.h"		// use new()
-#include "num.h"		// Use abs()
+#include "num.h"		// use interval_mod()
 #include "resonance.h"		// use Resonance
 #include "spectrum.h"		// Use Spectrum
 #include "utility.h"		// use fatal_error()
@@ -144,7 +146,7 @@ static double guess_error(const Guess_Assignments &ga, Assignment_Guess *ag,
 	    {
 	      double pos = interval_mod(r->frequency(),
 					alias_onto.min[a], alias_onto.max[a]);
-	      dev += abs(pos - center[a]) / threshold;
+	      dev += fabs(pos - center[a]) / threshold;
 	    }
 	}
       }
@@ -570,9 +572,9 @@ static bool assignment_is_atom_match(const char *pat, const char *nm)
 	/*
 	 * Pattern may be: atomName1 | atomName2 | atomName3
 	 */
-	char	*cp = strchr(pat, '|');
+	const char *cp = strchr(pat, '|');
 	if (cp) {
-		int	nmLen = strlen(nm);
+		size_t	nmLen = strlen(nm);
 
 		while (pat) {
 			if (strncmp(pat, nm, nmLen) == 0
