@@ -4,8 +4,7 @@
 #ifndef FORMAT_HEADER_INCLUDED
 #define FORMAT_HEADER_INCLUDED
 
-class istream;
-class ostream;
+#include <iostream>		// use istream, ostream
 
 class Condition;
 class Object_Table;
@@ -31,8 +30,8 @@ bool save_spectrum(Session &, Spectrum *, bool backup);
 // ----------------------------------------------------------------------------
 // Undo
 //
-void ornament_save_for_undo(Ornament *op, ostream &o, Object_Table &ids);
+void ornament_save_for_undo(Ornament *op, std::ostream &o, Object_Table &ids);
 Ornament *ornament_restore_for_undo(Session &, const Stringy &first_line,
-				    istream &strm, Object_Table &ids);
+				    std::istream &strm, Object_Table &ids);
 
 #endif
