@@ -18,14 +18,12 @@ int max(int a, int b);
 unsigned int max(unsigned int a, unsigned int b);
 double max(double a, double b);
 
-long abs(long a);
-double abs(double a);
-
 double floor(double x, double step);
 double floor(double x, double a, double b);
 double ceil(double x, double step);
-int round(double x);
-double round_multiple(double x, double unit);
+
+int nearest_int(double x);
+double nearest_multiple(double x, double unit);
 double interval_mod(double x, double a, double b);
 
 int bounded(int lo, int x, int hi);
