@@ -1,5 +1,6 @@
 // ----------------------------------------------------------------------------
 //
+#include <math.h>		// use fabs()
 
 #include "memalloc.h"		// use new()
 #include "nmrdata.h"		// Use NMR_Data
@@ -194,8 +195,8 @@ bool SpectrumData::heights_for_region(const IRegion &region, float *data) const
 
   if (!success)
     {
-      int size = region.volume();
-      for (int k = 0 ; k < size ; ++k)
+      size_t size = region.volume();
+      for (size_t k = 0 ; k < size ; ++k)
 	data[k] = 0;
     }
 
@@ -212,7 +213,7 @@ static bool retry_read(NMR_Data *nmr_data)
     return false;
 
   Stringy msg = formatted_string("Error reading data file %s\n"
-				 "Will use zeros.",
+				 "Will use zeros.\n",
 				 nmr_data->path().cstring());
   warn(msg.cstring());
   dont_warn = true;
@@ -699,7 +700,7 @@ double sample_spectrum_noise(SpectrumData *sp, int sample_count)
   float *values = new float[sample_count];
   IRegion r = sp->index_range();
   for (int k = 0 ; k < sample_count ; ++k)
-    values[k] = abs(sp->height_at_index(r.random_point()));
+    values[k] = (float) fabs(sp->height_at_index(r.random_point()));
   sort_floats(values, sample_count);
   double median = values[sample_count/2];
   delete values;
