@@ -2,11 +2,10 @@
 //
 #include <stdio.h>		// Use sprintf()
 #include <math.h>		// Use fabs()
-#include <string.h>		// Use memcpy()
 
 #include "spoint.h"
 #include "utility.h"		// Use fatal_error()
-#include "num.h"		// Use round()
+#include "num.h"		// Use nearest_int()
 
 static bool has_element(const IPoint &p, int e);
 
@@ -58,7 +57,7 @@ IPoint SPoint::rounded() const
 {
   int e[DIM];
   for (int d = 0 ; d < dimension() ; ++d)
-    e[d] = round((*this)[d]);
+    e[d] = nearest_int((*this)[d]);
   return IPoint(dimension(), e);
 }
 
@@ -606,11 +605,16 @@ IPoint IPoint::operator+(const IPoint &p) const
 
 // ----------------------------------------------------------------------------
 //
-int IPoint::product() const
+size_t IPoint::product() const
 {
-  int prod = 1;
-  for (int a = 0 ; a < dimension() ; ++a)
+  int d = dimension();
+  if (d == 0)
+    return 0;
+
+  size_t prod = 1;
+  for (int a = 0 ; a < d ; ++a)
     prod *= (*this)[a];
+
   return prod;
 }
 
@@ -792,10 +796,14 @@ int IRegion::longest_axis() const
 
 // ----------------------------------------------------------------------------
 //
-int IRegion::volume() const
+size_t IRegion::volume() const
 {
-  int vol = (dimension() == 0 ? 0 : 1);
-  for (int a = 0 ; a < dimension() ; ++a)
+  int d = dimension();
+  if (d == 0)
+    return 0;
+
+  size_t vol = 1;
+  for (int a = 0 ; a < d ; ++a)
     vol *= size(a);
 
   return vol;
@@ -937,191 +945,6 @@ void IRegion::translate(int delta, int axis)
   max[axis] += delta;
 }
 
-// ----------------------------------------------------------------------------
-//
-Subarray_Iterator::Subarray_Iterator(const IRegion &subreg,
-				     const IRegion &region,
-				     bool big_endian_indexing)
-{
-  if (!region.contains(subreg))
-    fatal_error("Subarray_Iterator(): Bad subregion.\n");
-
-  dim = region.dimension();
-  dimfast = (big_endian_indexing ? dim - 1 : 0);
-  dimstep = (big_endian_indexing ? -1 : 1);
-  dimend = (big_endian_indexing ? -1 : dim);
-  subregion = subreg;
-  done = subregion.empty();
-  if (!done)
-    {
-      pos = subregion.min;
-      indx = position_index(pos, region, big_endian_indexing);
-      step[dimfast] = 1;
-      for (int a = dimfast+dimstep ; a != dimend ; a += dimstep)
-	step[a] = step[a-dimstep] * region.size(a-dimstep);
-    }
-}
-
-// ----------------------------------------------------------------------------
-//
-int Subarray_Iterator::index() const
-  { return indx; }
-const IPoint &Subarray_Iterator::position() const
-  { return pos; }
-
-// ----------------------------------------------------------------------------
-//
-bool Subarray_Iterator::finished() const
-{
-  return done;
-}
-
-// ----------------------------------------------------------------------------
-//
-void Subarray_Iterator::next()
-{
-  int a;
-
-  for (a = dimfast ; a != dimend ; a += dimstep)
-    if (axis_step(a))
-      break;
-
-  done = (a == dimend);
-}
-
-// ----------------------------------------------------------------------------
-//
-int Subarray_Iterator::step_size(int a) const
-{
-  return step[a];
-}
-
-// ----------------------------------------------------------------------------
-// Step one unit along an axis going back to beginning if at end.
-// Return false if jump back to beginning occured.
-//
-bool Subarray_Iterator::axis_step(int a)
-{
-  pos[a] += 1;
-  indx += step[a];
-  if (pos[a] > subregion.max[a])
-    {
-      pos[a] = subregion.min[a];
-      indx -= subregion.size(a) * step[a];
-      return false;
-    }
-
-  return true;
-}
-
-// ----------------------------------------------------------------------------
-//
-IPoint index_position(int index, const IRegion &region,
-		      bool big_endian_indexing)
-{
-  IPoint p(region.dimension());
-
-  int dimfast = (big_endian_indexing ? region.dimension() - 1 : 0);
-  int dimstep = (big_endian_indexing ? -1 : 1);
-  int dimend = (big_endian_indexing ? -1 : region.dimension());
-  for (int a = dimfast ; a != dimend ; a += dimstep)
-    {
-      int size = region.size(a);
-      p[a] = index % size;
-      index /= size;
-    }
-
-  return p;
-}
-
-// ----------------------------------------------------------------------------
-//
-int position_index(const IPoint &point, const IRegion &region,
-		   bool big_endian_indexing)
-{
-  int index = 0, step = 1;
-
-  int dimfast = (big_endian_indexing ? region.dimension() - 1 : 0);
-  int dimstep = (big_endian_indexing ? -1 : 1);
-  int dimend = (big_endian_indexing ? -1 : region.dimension());
-  for (int a = dimfast ; a != dimend ; a += dimstep)
-    {
-      index += (point[a] - region.min[a]) * step;
-      step *= region.size(a);
-    }
-
-  return index;
-}
-
-// ----------------------------------------------------------------------------
-//
-int array_step(int axis, const IRegion &region, bool big_endian_indexing)
-{
-  int step = 1;
-
-  int dimfast = (big_endian_indexing ? region.dimension() - 1 : 0);
-  int dimstep = (big_endian_indexing ? -1 : 1);
-  for (int a = dimfast ; a != axis ; a += dimstep)
-    step *= region.size(a);
-
-  return step;
-}
-
-// ----------------------------------------------------------------------------
-//
-void little_to_big_endian_indexing(const IRegion &region, float *le, float *be)
-{
-  //
-  // Optimization: Copy data a row at a time along the longest axis.
-  //
-  IRegion base = region;
-  int long_axis = region.longest_axis();
-  base.max[long_axis] = base.min[long_axis];
-
-  Subarray_Iterator li(base, region, false);
-
-  int lstep = li.step_size(long_axis);
-  int bstep = array_step(long_axis, region, true);
-  int row_length = region.size(long_axis);
-
-  for ( ; !li.finished() ; li.next())
-    {
-      float *from = le + li.index();
-      float *to = be + position_index(li.position(), region, true);
-      for (int k = 0 ; k < row_length ; ++k)
-	to[k * bstep] = from[k * lstep];
-    }
-}
-
-// ----------------------------------------------------------------------------
-//
-void big_to_little_endian_indexing(const IRegion &region, float *be, float *le)
-{
-  int dim = region.dimension();
-
-  int volume = region.volume();
-  int bi = 0, be_step = volume / region.size(0);
-  IPoint p = region.min;
-  for (int li = 0 ; li < volume ; ++li)
-    {
-      le[li] = be[bi];
-
-      p[0] += 1;
-      int bstep = be_step;
-      bi += bstep;
-      for (int a = 0 ; a < dim && p[a] > region.max[a] ; ++a)
-	{
-	  p[a] = region.min[a];
-	  bi -= bstep * region.size(a);
-	  if (a+1 == dim)
-	    return;
-	  p[a+1] += 1;
-	  bstep /= region.size(a+1);
-	  bi += bstep;
-	}
-    }
-}
-
 // ----------------------------------------------------------------------------
 //
 double distance(const SPoint &p1, const SPoint &p2)
@@ -1139,21 +962,6 @@ double distance(const SPoint &p1, const SPoint &p2)
   return sqrt(d2);
 }
 
-// ----------------------------------------------------------------------------
-//
-void copy_array(const void *source, void *destination, int element_size,
-		const IRegion &rs, const IRegion &rd)
-{
-  IRegion common = rs;
-  common.clip(rd);
-
-  Subarray_Iterator si(common, rs, true), di(common, rd, true);
-  for ( ; !si.finished() ; si.next(), di.next())
-    memcpy((char *) destination + di.index() * element_size,
-	   (char *) source + si.index() * element_size,
-	   element_size);
-}
-
 // ----------------------------------------------------------------------------
 //
 const char *point_format(const SPoint &point, const char *fmt, bool brackets)
