@@ -8,11 +8,11 @@
 #include "reporter.h"		// use Reporter
 #include "session.h"		// use Session
 #include "stringc.h"		// use Stringy
-#include "system.h"		// use start_netscape()
+#include "system.h"		// use show_url()
 #include "uidialogs.h"		// use show_manual_url()
 #include "uimain.h"		// use query()
 #include "utility.h"		// use warning()
-#include "winsystem.h"		// use Widget, show_url()
+#include "winsystem.h"		// use Widget
 
 // ----------------------------------------------------------------------------
 // URL is retrieved from option database.
@@ -33,20 +33,14 @@ void show_manual_url(Session &s, const Stringy &manual_url)
   Stringy page = (manual_url.is_empty() ? Stringy("index.html") : manual_url);
   Stringy path = file_path(mandir, page);
   Stringy url = "file://" + path;
-  if (!s.window_system().show_url(url))
+  Stringy error_msg;
+  if (!show_url(url, &error_msg))
     {
-      if (query(s,
-		"Sparky wants to show you part of the manual:\n\n\t" + path +
-		"\n\nWould you like to start Netscape to display this page?",
-		"Start Netscape", "Cancel") == 1)
-	{
-	  if (!start_netscape(url))
-	    {
-	      Reporter &rr = s.reporter();
-	      rr.warning("Couldn't start Netscape.\n"
-			 "You can use any web browser to look at URL:\n\t"
-			 "%s", url.cstring());
-	    }
-	}
+      Reporter &rr = s.reporter();
+      rr.warning("Unable to show:\n"
+		 "%s\n"
+		 "You can view this in any web browser.\n\n"
+		 "%s",
+		 url.cstring(), error_msg.cstring());
     }
 }
