@@ -9,7 +9,7 @@
 //
 
 #include <float.h>		// use FLT_MAX
-#include <math.h>		// use sqrt(), log()
+#include <math.h>		// use sqrt(), log(), fabs()
 
 #include "assigncopy.h"		// Use assignment_copy()
 #include "assignguess.h"	// use Guess_Assignments
@@ -181,7 +181,7 @@ const Color &Contour_Parameters::level_color(double level) const
     return *(Color *) colors[0];
 
   double e = log(r) / log(levels.factor);
-  int i = round(colors.size() * e / levels.levels);
+  int i = nearest_int(colors.size() * e / levels.levels);
   if (i < 0)
     i = 0;
   else if (i >= colors.size())
@@ -1077,8 +1077,8 @@ void View::buttonup_action()
 void View::drag(double x, double y)
 {
 	if (!pick.down ||		// We didn't get button down event.
-	    (abs(x - pick.downX) < DRAGMIN * pixel_size(X) &&
-	     abs(y - pick.downY) < DRAGMIN * pixel_size(Y)))
+	    (fabs(x - pick.downX) < DRAGMIN * pixel_size(X) &&
+	     fabs(y - pick.downY) < DRAGMIN * pixel_size(Y)))
 	  return;
 
 	if (pick.drag)
@@ -2113,7 +2113,7 @@ static int in_plane(const SPoint &p, View *v)
     {
       int zaxis = v->axis_order()[2];
       double z = sp->map(p[zaxis], zaxis, PPM, INDEX);
-      double z_display = round(sp->map(v->center(zaxis), zaxis, PPM, INDEX));
+      double z_display = nearest_int(sp->map(v->center(zaxis), zaxis, PPM, INDEX));
       if (z - z_display > .5)
 	plane = 1;
       else if (z - z_display < -.5)
@@ -2470,8 +2470,8 @@ void View::move_ornament()
 	dxdata = pick.lastX - pick.downX;
 	dydata = pick.lastY - pick.downY;
 
-	if (abs(dxdata) < MINMOVE * pixel_size(X) &&
-	    abs(dydata) < MINMOVE * pixel_size(Y))
+	if (fabs(dxdata) < MINMOVE * pixel_size(X) &&
+	    fabs(dydata) < MINMOVE * pixel_size(Y))
 		return;
 
 	//
