@@ -2,7 +2,7 @@
 // Read NMR data processed using Varian's VNMR program
 //
 
-#include <fstream.h>		// Use ifstream
+#include <fstream>		// Use ifstream
 #include <stdio.h>		// Use FILE *
 #include <string.h>		// Use strchr()
 
@@ -14,6 +14,7 @@
 #include "nmrdata.h"		// Use NMR_Data
 #include "spoint.h"		// Use IPoint, SPoint
 #include "stringc.h"		// Use Stringy
+#include "subarray.h"		// use position_index()
 #include "system.h"		// Use file_exists(), file_path(), file_size()
 #include "utility.h"		// use array_size(), fatal_error()
 
@@ -128,7 +129,7 @@ private:
   int block_header_size;
   bool transposed;
 
-  long block_location(const IPoint &block);
+  offset_type block_location(const IPoint &block);
 };
 
 // ----------------------------------------------------------------------------
@@ -188,7 +189,7 @@ static bool check_phasefile(FILE *fp, const Stringy &file, const IPoint &sz,
 			    int *block_header_size, bool *transposed,
 			    IPoint *bsize, Stringy *error_msg);
 static bool unquote(const Stringy &quoted, Stringy *unquoted);
-static bool read_procpar_entry(istream &strm,
+static bool read_procpar_entry(std::istream &strm,
 			       Stringy *tag, Stringy *value, Stringy *next);
 static bool read_procpar(const Stringy &path, const List &nucleus_names,
 			 IPoint *size,
@@ -340,25 +341,27 @@ static bool check_phasefile(FILE *fp, const Stringy &file, const IPoint &sz,
       return false;
     }
 
-  unsigned long expected_size = (VNMR_FILE_HEADER_SIZE + fh.nblocks *
-				 (fh.nbheaders * VNMR_BLOCK_HEADER_SIZE +
-				  4 * fh.np * fh.ntraces));  
-  unsigned long size = file_size(file);
+  offset_type expected_size = (VNMR_FILE_HEADER_SIZE + fh.nblocks *
+			       (fh.nbheaders * VNMR_BLOCK_HEADER_SIZE +
+				4 * fh.np * fh.ntraces));  
+  offset_type size = file_size(file);
   if (size < expected_size)
     {
-      *error_msg = formatted_string("%s is smaller (%d bytes) "
-				    "than expected (%d bytes)",
-				    file.cstring(), size, expected_size);
+      *error_msg = formatted_string("%s is smaller (%ld bytes) "
+				    "than expected (%ld bytes)",
+				    file.cstring(),
+				    static_cast<long>(size),
+				    static_cast<long>(expected_size));
       return false;
     }
 
-  *block_header_size = fh.nbheaders * VNMR_BLOCK_HEADER_SIZE;
+  *block_header_size = static_cast<int>(fh.nbheaders * VNMR_BLOCK_HEADER_SIZE);
 
   *transposed = (fh.status & VNMR_S_TRANSF);
 
   *bsize = IPoint(dim);
-  (*bsize)[0] = fh.np;
-  (*bsize)[dim-1] = fh.ntraces;
+  (*bsize)[0] = static_cast<int> (fh.np);
+  (*bsize)[dim-1] = static_cast<int> (fh.ntraces);
   if (dim == 3)
     (*bsize)[1] = 1;
 
@@ -369,7 +372,7 @@ static bool check_phasefile(FILE *fp, const Stringy &file, const IPoint &sz,
 //
 procpar::procpar(const Stringy &path)
 {
-  ifstream pp(path.cstring());
+  std::ifstream pp(path.cstring());
 
   Stringy tag, value, next;
   while (read_procpar_entry(pp, &tag, &value, &next))
@@ -416,8 +419,8 @@ bool procpar::find(const Stringy &tag, Stringy *value) const
 static bool unquote(const Stringy &quoted, Stringy *unquoted)
 {
   const char *q = quoted.cstring();
-  char *q1 = strchr(q, '\"');
-  char *q2 = strrchr(q, '\"');
+  const char *q1 = strchr(q, '\"');
+  const char *q2 = strrchr(q, '\"');
   if (q1 && q2 && q1 != q2)
     *unquoted = substring(q1 + 1, q2);
 
@@ -426,7 +429,7 @@ static bool unquote(const Stringy &quoted, Stringy *unquoted)
 
 // ----------------------------------------------------------------------------
 //
-static bool read_procpar_entry(istream &strm,
+static bool read_procpar_entry(std::istream &strm,
 			       Stringy *tag, Stringy *value, Stringy *next)
 {
   while (next->is_empty() && stream_line(strm, next)) ;
@@ -613,8 +616,8 @@ VNMR_2D_Block_File::~VNMR_2D_Block_File()
 //
 bool VNMR_2D_Block_File::read_block(const IPoint &block, float *values)
 {
-  long position = block_location(block);
-  long size = block_volume();
+  offset_type position = block_location(block);
+  offset_type size = block_volume();
 
   struct vnmr_datablockhead bh;
 
@@ -650,11 +653,11 @@ bool VNMR_2D_Block_File::write_block(const IPoint &, float *)
 
 // ----------------------------------------------------------------------------
 //
-long VNMR_2D_Block_File::block_location(const IPoint &block)
+offset_type VNMR_2D_Block_File::block_location(const IPoint &block)
 {
-  long block_number = position_index(block, block_space(), true);
-  long data_start = VNMR_FILE_HEADER_SIZE;
-  long block_size = block_header_size + block_volume() * (long) sizeof(float);
+  offset_type block_number = position_index(block, block_space(), true);
+  offset_type data_start = VNMR_FILE_HEADER_SIZE;
+  offset_type block_size = block_header_size + block_volume() * sizeof(float);
 
   return data_start + block_number * block_size;
 }
